<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Media.Devices.Core

Windows Runtime (WinRT) APIs for for the `Windows.Media.Devices.Core` namespace.

This package provides the `winrt.windows.media.devices.core` module.
